==> jc-1.4.0.tar.gz: gnu/javax/rmi/PortableServer.h <==
// public class gnu.javax.rmi.PortableServer

// class file dependencies
// @dep_class 2e53fbaf54565a39 gnu_javax_rmi_PortableServer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_javax_rmi_PortableServer_H_
#define _JC_gnu_javax_rmi_PortableServer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_rmi_CORBA_ObjectImpl$object;
struct _jc_javax_rmi_CORBA_Tie$object;

// Typedefs
typedef struct _jc_gnu_javax_rmi_PortableServer$sub_refs	_jc_gnu_javax_rmi_PortableServer$sub_refs;
typedef struct _jc_gnu_javax_rmi_PortableServer$sub_nonrefs	_jc_gnu_javax_rmi_PortableServer$sub_nonrefs;
typedef struct _jc_gnu_javax_rmi_PortableServer$refs	_jc_gnu_javax_rmi_PortableServer$refs;
typedef struct _jc_gnu_javax_rmi_PortableServer$nonrefs	_jc_gnu_javax_rmi_PortableServer$nonrefs;
typedef struct _jc_gnu_javax_rmi_PortableServer$object	_jc_gnu_javax_rmi_PortableServer$object;

typedef struct _jc_gnu_javax_rmi_PortableServer$fields_struct	_jc_gnu_javax_rmi_PortableServer$fields_struct;
typedef const struct _jc_gnu_javax_rmi_PortableServer$vmethods	_jc_gnu_javax_rmi_PortableServer$vmethods;
typedef const struct _jc_gnu_javax_rmi_PortableServer$vtable	_jc_gnu_javax_rmi_PortableServer$vtable;
typedef const struct _jc_gnu_javax_rmi_PortableServer$vtype	_jc_gnu_javax_rmi_PortableServer$vtype;

// Class fields structure
struct _jc_gnu_javax_rmi_PortableServer$fields_struct {
	struct _jc_java_lang_Object$object	*NO__5fTIE;
	struct _jc_java_util_Hashtable$object	*tieCache;
};
extern _jc_gnu_javax_rmi_PortableServer$fields_struct _jc_gnu_javax_rmi_PortableServer$class_fields;

// Constructors
extern void _jc_gnu_javax_rmi_PortableServer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_javax_rmi_PortableServer$object *);

// Static methods
extern void _jc_gnu_javax_rmi_PortableServer$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_gnu_javax_rmi_PortableServer$method$exportObject$f24f2fffff6dde7d(_jc_env *, struct _jc_object *);
extern struct _jc_object *_jc_gnu_javax_rmi_PortableServer$method$getStubFromObjectImpl$4aa7ce7da661327a(_jc_env *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *, struct _jc_java_lang_Class$object *);
extern struct _jc_object *_jc_gnu_javax_rmi_PortableServer$method$getStubFromTie$32acbb0a8686f94c(_jc_env *, struct _jc_object *);
extern struct _jc_object *_jc_gnu_javax_rmi_PortableServer$method$getTieFromClass$838073252ebfdc0a(_jc_env *, struct _jc_java_lang_Class$object *);
extern struct _jc_object *_jc_gnu_javax_rmi_PortableServer$method$getTieFromRemote$1f70704e10843e3d(_jc_env *, struct _jc_object *);
extern struct _jc_object *_jc_gnu_javax_rmi_PortableServer$method$toStub$eb510defe3584b97(_jc_env *, struct _jc_object *);
extern void _jc_gnu_javax_rmi_PortableServer$method$unexportObject$be7fa0efab735c7e(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_gnu_javax_rmi_PortableServer$vmethods {
};

// Vtable
struct _jc_gnu_javax_rmi_PortableServer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_javax_rmi_PortableServer$vmethods	gnu_javax_rmi_PortableServer;
};

// Vtype
struct _jc_gnu_javax_rmi_PortableServer$vtype {
	_jc_type			type;
	_jc_gnu_javax_rmi_PortableServer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_javax_rmi_PortableServer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_javax_rmi_PortableServer$refs {
    _jc_gnu_javax_rmi_PortableServer$sub_refs	gnu_javax_rmi_PortableServer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_javax_rmi_PortableServer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_javax_rmi_PortableServer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_javax_rmi_PortableServer$sub_nonrefs	gnu_javax_rmi_PortableServer;
};

// Object instance structure
struct _jc_gnu_javax_rmi_PortableServer$object {
	_jc_gnu_javax_rmi_PortableServer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_javax_rmi_PortableServer$vtype	*vtype;
	_jc_gnu_javax_rmi_PortableServer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_javax_rmi_PortableServer$vtype _jc_gnu_javax_rmi_PortableServer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_javax_rmi_PortableServer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_javax_rmi_PortableServer$class_object;

#endif	/* _JC_gnu_javax_rmi_PortableServer_H_ */

==> jc-1.4.6.tar.gz: gnu/javax/rmi/PortableServer.h <==
// public class gnu.javax.rmi.PortableServer

// class file dependencies
// @dep_class 2e53fbaf54565a39 gnu_javax_rmi_PortableServer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_javax_rmi_PortableServer_H_
#define _JC_gnu_javax_rmi_PortableServer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_rmi_CORBA_ObjectImpl$object;
struct _jc_javax_rmi_CORBA_Tie$object;

// Typedefs
typedef struct _jc_gnu_javax_rmi_PortableServer$sub_refs	_jc_gnu_javax_rmi_PortableServer$sub_refs;
typedef struct _jc_gnu_javax_rmi_PortableServer$sub_nonrefs	_jc_gnu_javax_rmi_PortableServer$sub_nonrefs;
typedef struct _jc_gnu_javax_rmi_PortableServer$refs	_jc_gnu_javax_rmi_PortableServer$refs;
typedef struct _jc_gnu_javax_rmi_PortableServer$nonrefs	_jc_gnu_javax_rmi_PortableServer$nonrefs;
typedef struct _jc_gnu_javax_rmi_PortableServer$object	_jc_gnu_javax_rmi_PortableServer$object;

typedef struct _jc_gnu_javax_rmi_PortableServer$fields_struct	_jc_gnu_javax_rmi_PortableServer$fields_struct;
typedef const struct _jc_gnu_javax_rmi_PortableServer$vmethods	_jc_gnu_javax_rmi_PortableServer$vmethods;
typedef const struct _jc_gnu_javax_rmi_PortableServer$vtable	_jc_gnu_javax_rmi_PortableServer$vtable;
typedef const struct _jc_gnu_javax_rmi_PortableServer$vtype	_jc_gnu_javax_rmi_PortableServer$vtype;

// Class fields structure
struct _jc_gnu_javax_rmi_PortableServer$fields_struct {
	struct _jc_java_lang_Object$object	*NO__5fTIE;
	struct _jc_java_util_Hashtable$object	*tieCache;
};
extern _jc_gnu_javax_rmi_PortableServer$fields_struct _jc_gnu_javax_rmi_PortableServer$class_fields;

// Constructors
extern void _jc_gnu_javax_rmi_PortableServer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_javax_rmi_PortableServer$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_javax_rmi_PortableServer$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_gnu_javax_rmi_PortableServer$method$exportObject$f24f2fffff6dde7d(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_javax_rmi_PortableServer$method$getStubFromObjectImpl$4aa7ce7da661327a(_jc_env *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_javax_rmi_PortableServer$method$getStubFromTie$32acbb0a8686f94c(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_javax_rmi_PortableServer$method$getTieFromClass$838073252ebfdc0a(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_javax_rmi_PortableServer$method$getTieFromRemote$1f70704e10843e3d(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_javax_rmi_PortableServer$method$toStub$eb510defe3584b97(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_javax_rmi_PortableServer$method$unexportObject$be7fa0efab735c7e(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_javax_rmi_PortableServer$vmethods {
};

// Vtable
struct _jc_gnu_javax_rmi_PortableServer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_javax_rmi_PortableServer$vmethods	gnu_javax_rmi_PortableServer;
};

// Vtype
struct _jc_gnu_javax_rmi_PortableServer$vtype {
	_jc_type			type;
	_jc_gnu_javax_rmi_PortableServer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_javax_rmi_PortableServer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_javax_rmi_PortableServer$refs {
    _jc_gnu_javax_rmi_PortableServer$sub_refs	gnu_javax_rmi_PortableServer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_javax_rmi_PortableServer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_javax_rmi_PortableServer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_javax_rmi_PortableServer$sub_nonrefs	gnu_javax_rmi_PortableServer;
};

// Object instance structure
struct _jc_gnu_javax_rmi_PortableServer$object {
	_jc_gnu_javax_rmi_PortableServer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_javax_rmi_PortableServer$vtype	*vtype;
	_jc_gnu_javax_rmi_PortableServer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_javax_rmi_PortableServer$vtype _jc_gnu_javax_rmi_PortableServer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_javax_rmi_PortableServer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_javax_rmi_PortableServer$class_object;

#endif	/* _JC_gnu_javax_rmi_PortableServer_H_ */
